@@ -153,7 +153,7 @@ extern void resetparts(char *, char *, char *);
 extern void iamop(char *, int);
 extern void initpubmsgs(char *);
 extern void freepubmsguser(char *, char *, char *);
-extern void lockchan(char *, int, char *, char *);
+extern void lockchan(char *, char *, int, char *, char *);
 extern void unlockchan(char *, char *, char *);
 extern void clearflood(char *, char *, char *);
 extern void newchannel(char *);
