@@ -30,6 +30,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 int emptyline(char *);
 int iscomment(char *);
 int isnumber(char *);
+int isserver(char *);
 int isansi(char *);
 int isaction(char *);
 int isctcp(char *);
@@ -320,6 +321,24 @@ int isnumber(char *line)
 	return 1;
 }
 
+int isserver(char *line)
+{
+	int i;
+	int length;
+	int dots;
+
+	for(i = 0, length = strlen(line), dots = 0; i < length; i++) {
+		if(line[i] == '.') {
+			dots++;
+		}
+	}
+	if(wordcount(line) >= 2 && dots >= 2) {
+		return 1;
+	} else {
+		return 0;
+	}
+}
+
 int parse(char *from, int pos, char *delim, char *to, int to_length, int fixed)
 {
         int i;
