@@ -24,17 +24,13 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 /* global prototype definition */
-extern char *stripnick(char *);
-extern char *striphost(char *);
-extern char *strsep3(char *, char *, char *);
-extern char *__strsep3(char *, char *, char *);
-extern char *getnextparam(char *, char *);
 extern int isansi(char *);
 extern int isaction(char *);
 extern int isctcp(char *);
 extern int emptyline(char *);
 extern int iscomment(char *);
 extern int isnumber(char *);
+extern int isserver(char *);
 extern int wordcount(char *);
 extern int parse(char *, int, char *, char *, int, int);
 extern void striplf(char *);
