@@ -103,6 +103,7 @@ enum WHICHCOMMAND_RETURN_VALUES {
 	OER_WHICHCOMMAND_TOPIC_REFRESH,
 	OER_WHICHCOMMAND_TOPIC_SWAP,
 	OER_WHICHCOMMAND_LOCK,
+	OER_WHICHCOMMAND_LOCKU,
 	OER_WHICHCOMMAND_UNLOCK,
 	OER_WHICHCOMMAND_RANDOM_KICK,
 	OER_WHICHCOMMAND_RANDOM_BANKICK,
@@ -237,6 +238,7 @@ enum OER_DEBUG_LEVELS {
 #define OER_PART_EXPIRE 1800
 #define OER_BURST_JOINS OER_JOINS / 3
 #define OER_BURST_JOINS_LIMIT OER_JOINS / 2
+#define OER_DELAY_BETWEEN_REJOINS 10
 #define OER_AUTO_REJOIN_TIME 3
 #define OER_QUOTE_INTERVAL 300
 #define OER_ALLOWED_PARTS OER_PARTS / 5
@@ -290,7 +292,7 @@ enum OER_DEBUG_LEVELS {
 #define OER_HELP "For a complete command reference go to http://oer.equnet.org/help.html"
 #define DEFAULT_NICKBK_MESSAGE "prohibited nick"
 #define OER_REALNAME "http://oer.equnet.org/help.html"
-#define OER_COPYRIGHT1 "oer version 1.0-29, Copyright (C) 2000 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer version 1.0-30, Copyright (C) 2000 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
@@ -318,6 +320,7 @@ struct locked {
 	int locked;
 	int unlocked;
 	int auto_unlock;
+	char reason[STRINGLEN + 1];
 	char nick[NICKLEN + 1];
 	char host[HOSTLEN + 1];
 };
