@@ -974,7 +974,8 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_LOCK:
-		oer_debug(OER_DEBUG_INFO, "parsecommand->LOCK\n");
+	case OER_WHICHCOMMAND_LOCKU:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->LOCK/LOCKU\n");
 		proceed = 0;
 		if(isadmin(channel, host)) {
 			proceed = 1;
@@ -988,13 +989,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		if(!amiop(channel)) {
 			return;
 		}
-		ppos = 0;
-		ppos = parse(restptr, ppos, " ", p1, STRINGLEN, 0);
-		if((strlen(p1) > 0) && !strcasecmp(p1, "auto")) {
-			lockchan(channel, 1, nick, host);
-		} else {
-			lockchan(channel, 0, nick, host);
-		}
+		lockchan(channel, restptr, (which == OER_WHICHCOMMAND_LOCK) ? 0 : 1, nick, host);
 		return;
 	case OER_WHICHCOMMAND_UNLOCK:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->UNLOCK\n");
